==> libqt4pas_2.4.orig.tar.gz: splitbuild-qt4pas-V2.4_Qt4.5.3/src/qpushbutton_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QPUSHBUTTON_C_H
#define QPUSHBUTTON_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QPushButtonH QPushButton_create(QWidgetH parent);
C_EXPORT void QPushButton_destroy(QPushButtonH handle);
C_EXPORT QPushButtonH QPushButton_create2(PWideString text, QWidgetH parent);
C_EXPORT QPushButtonH QPushButton_create3(const QIconH icon, PWideString text, QWidgetH parent);
C_EXPORT void QPushButton_sizeHint(QPushButtonH handle, PSize retval);
C_EXPORT void QPushButton_minimumSizeHint(QPushButtonH handle, PSize retval);
C_EXPORT bool QPushButton_autoDefault(QPushButtonH handle);
C_EXPORT void QPushButton_setAutoDefault(QPushButtonH handle, bool p1);
C_EXPORT bool QPushButton_isDefault(QPushButtonH handle);
C_EXPORT void QPushButton_setDefault(QPushButtonH handle, bool p1);
C_EXPORT void QPushButton_setMenu(QPushButtonH handle, QMenuH menu);
C_EXPORT QMenuH QPushButton_menu(QPushButtonH handle);
C_EXPORT void QPushButton_setFlat(QPushButtonH handle, bool p1);
C_EXPORT bool QPushButton_isFlat(QPushButtonH handle);
C_EXPORT void QPushButton_showMenu(QPushButtonH handle);

#endif

==> libqt4pas_2.5.orig.tar.gz: splitbuild-qt4pas-V2.5_Qt4.5.3/src/qpushbutton_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QPUSHBUTTON_C_H
#define QPUSHBUTTON_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QPushButtonH QPushButton_create(QWidgetH parent);
C_EXPORT void QPushButton_destroy(QPushButtonH handle);
C_EXPORT QPushButtonH QPushButton_create2(PWideString text, QWidgetH parent);
C_EXPORT QPushButtonH QPushButton_create3(const QIconH icon, PWideString text, QWidgetH parent);
C_EXPORT void QPushButton_sizeHint(QPushButtonH handle, PSize retval);
C_EXPORT void QPushButton_minimumSizeHint(QPushButtonH handle, PSize retval);
C_EXPORT bool QPushButton_autoDefault(QPushButtonH handle);
C_EXPORT void QPushButton_setAutoDefault(QPushButtonH handle, bool AnonParam1);
C_EXPORT bool QPushButton_isDefault(QPushButtonH handle);
C_EXPORT void QPushButton_setDefault(QPushButtonH handle, bool AnonParam1);
C_EXPORT void QPushButton_setMenu(QPushButtonH handle, QMenuH menu);
C_EXPORT QMenuH QPushButton_menu(QPushButtonH handle);
C_EXPORT void QPushButton_setFlat(QPushButtonH handle, bool AnonParam1);
C_EXPORT bool QPushButton_isFlat(QPushButtonH handle);
C_EXPORT void QPushButton_showMenu(QPushButtonH handle);

#endif
